# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from zypev1.api_helper import APIHelper
from zypev1.controllers.playlist_entitlements_controller import PlaylistEntitlementsController


class PlaylistEntitlementsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(PlaylistEntitlementsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = PlaylistEntitlementsController(cls.config, cls.response_catcher)

    # Testcase for testing endpoint Delete a Playlist Entitlement
    def test_delete_a_playlist_entitlement_1(self):
        # Parameters for the API call
        consumer_id = '5a0474c6aff38b1df4000036'
        id = '574decf509838854f1000183'

        # Perform the API call through the SDK function
        self.controller.consumers_playlists_by_consumer_id_and_id_delete(consumer_id, id)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 204)

        # Test headers
        expected_headers = {}
        expected_headers['content-type'] = None

        self.assertTrue(TestHelper.match_headers(expected_headers, self.response_catcher.response.headers))


