# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TransactionMetadata(object):

    """Implementation of the 'TransactionMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        created_at (string): TODO: type description here.
        expires_at (string): TODO: type description here.
        site_id (string): TODO: type description here.
        status (string): TODO: type description here.
        stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e (string): TODO:
            type description here.
        updated_at (string): TODO: type description here.
        amount (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "created_at": 'created_at',
        "expires_at": 'expires_at',
        "site_id": 'site_id',
        "status": 'status',
        "stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e": 'stripe_id: ch_1AztEoChyLVkXdp8yRoQlZ5e',
        "updated_at": 'updated_at',
        "amount": 'amount'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 expires_at=None,
                 site_id=None,
                 status=None,
                 stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e=None,
                 updated_at=None,
                 amount=None):
        """Constructor for the TransactionMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.expires_at = expires_at
        self.site_id = site_id
        self.status = status
        self.stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e = stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e
        self.updated_at = updated_at
        self.amount = amount

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        created_at = dictionary.get('created_at')
        expires_at = dictionary.get('expires_at')
        site_id = dictionary.get('site_id')
        status = dictionary.get('status')
        stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e = dictionary.get('stripe_id: ch_1AztEoChyLVkXdp8yRoQlZ5e')
        updated_at = dictionary.get('updated_at')
        amount = dictionary.get('amount')

        # Return an object of this model
        return cls(id,
                   created_at,
                   expires_at,
                   site_id,
                   status,
                   stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e,
                   updated_at,
                   amount)
