# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AddZobjectSToVideoRequest(object):

    """Implementation of the 'Add Zobject(s) to Video request' model.

    TODO: type model description here.

    Attributes:
        zobject_id (object): Zobject IDs to be added

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "zobject_id": 'zobject_id'
    }

    def __init__(self,
                 zobject_id=None):
        """Constructor for the AddZobjectSToVideoRequest class"""

        # Initialize members of the class
        self.zobject_id = zobject_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        zobject_id = dictionary.get('zobject_id')

        # Return an object of this model
        return cls(zobject_id)
