# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VideoManifest(object):

    """Implementation of the 'VideoManifest' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        url (string):
            api.us-east-1.amazonaws.com/latest/eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1
            NiJ9.eyJhZF91cmwiOiJodHRwczovL3p5cGVsaXZlLWxoLmFrYW1haWhkLXN0YWdpbm
            cubmV0L2kvZGVmYXVsdF8xQEFzdGFjb21tL21hc3Rlci5tM3U4P3N0YXJ0PTE1MDc1N
            jE3MjkmaGRudHM9ZXhwJTNEMTUwODUzNTMxNSU3RWFjbCUzRCUyRiolNDBBc3RhY29t
            bSUyRiolN0VobWFjJTNENjhjMDU2MjRjNzQ0YzY4MWUyNDQ2YjcyZGFjYzllN2U1MWN
            hYTA5ZWRjZjgyNTk5ZTUwYzI0MmQ2ZjQzMWQ2MSIsInZpZGVvX2lkIjoiNTlkYjkxMW
            Y2ZTgyYzIwMDAxMDAwMDBlIiwic2l0ZV9pZCI6IjU5ODMzMmVlODExMzc4MDAwMTAwM
            DBlNyIsImRhdGUiOiIyMDE3LTEwLTE5VDIxOjM1OjE1KzAwOjAwIiwiZW52Ijoic3Rh
            Z2UifQ.v2H5T5BHO5jYFE2AQ1TW7EP33624up7oM3KuNOg6BBY

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "url": 'url'
    }

    def __init__(self,
                 id=None,
                 url=None):
        """Constructor for the VideoManifest class"""

        # Initialize members of the class
        self.id = id
        self.url = url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        url = dictionary.get('url')

        # Return an object of this model
        return cls(id,
                   url)
