# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Original(object):

    """Implementation of the 'original' model.

    TODO: type model description here.

    Attributes:
        url (string): TODO: type description here.
        size (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "url": 'url',
        "size": 'size'
    }

    def __init__(self,
                 url=None,
                 size=None):
        """Constructor for the Original class"""

        # Initialize members of the class
        self.url = url
        self.size = size

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        url = dictionary.get('url')
        size = dictionary.get('size')

        # Return an object of this model
        return cls(url,
                   size)
