# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class File24(object):

    """Implementation of the 'File24' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        height (float): TODO: type description here.
        width (float): TODO: type description here.
        quality (string): TODO: type description here.
        url (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "height": 'height',
        "width": 'width',
        "quality": 'quality',
        "url": 'url'
    }

    def __init__(self,
                 id=None,
                 height=None,
                 width=None,
                 quality=None,
                 url=None):
        """Constructor for the File24 class"""

        # Initialize members of the class
        self.id = id
        self.height = height
        self.width = width
        self.quality = quality
        self.url = url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        height = dictionary.get('height')
        width = dictionary.get('width')
        quality = dictionary.get('quality')
        url = dictionary.get('url')

        # Return an object of this model
        return cls(id,
                   height,
                   width,
                   quality,
                   url)
