# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from zypev1.api_helper import APIHelper
from zypev1.controllers.transactions_controller import TransactionsController


class TransactionsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(TransactionsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = TransactionsController(cls.config, cls.response_catcher)

    # Testcase for testing endpoint Delete Transaction
    def test_delete_transaction_1(self):
        # Parameters for the API call
        id = '5a09c873f716e4000100003e'

        # Perform the API call through the SDK function
        self.controller.transactions_by_id_delete(id)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 204)

        # Test headers
        expected_headers = {}
        expected_headers['content-type'] = None

        self.assertTrue(TestHelper.match_headers(expected_headers, self.response_catcher.response.headers))


