# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Geography(object):

    """Implementation of the 'Geography' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        countries (object): List of countries supplied by you

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "countries": 'countries'
    }

    def __init__(self,
                 id=None,
                 countries=None):
        """Constructor for the Geography class"""

        # Initialize members of the class
        self.id = id
        self.countries = countries

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        countries = dictionary.get('countries')

        # Return an object of this model
        return cls(id,
                   countries)
